from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup
from ..............Internal import Conversions
from .............. import enums
from .............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TmDensityCls:
	"""TmDensity commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tmDensity", core, parent)

	def set(self, ptrs_tp_time_dens: enums.PtrsTpTimeDensityAll, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:PTRS:TP:TMDensity \n
		Snippet: driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.ptrs.tp.tmDensity.set(ptrs_tp_time_dens = enums.PtrsTpTimeDensityAll.TD1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the higher-layer parameter timeDensity. \n
			:param ptrs_tp_time_dens: TD1| TD2 TD1 LPT-RS = 1 TD2 LPT-RS = 2
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
		"""
		param = Conversions.enum_scalar_to_str(ptrs_tp_time_dens, enums.PtrsTpTimeDensityAll)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:PTRS:TP:TMDensity {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, userNull=repcap.UserNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.PtrsTpTimeDensityAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:SCHed:CELL<CC(CH0)>:SUBF<SF(ST0)>:USER<US(DIR0)>:BWPart<BWP(GR0)>:ALLoc<AL(USER0)>:PUSCh:PTRS:TP:TMDensity \n
		Snippet: value: enums.PtrsTpTimeDensityAll = driver.source.bb.nr5G.scheduling.cell.subf.user.bwPart.alloc.pusch.ptrs.tp.tmDensity.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, userNull = repcap.UserNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the higher-layer parameter timeDensity. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'BwPart')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: ptrs_tp_time_dens: TD1| TD2 TD1 LPT-RS = 1 TD2 LPT-RS = 2"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._cmd_group.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:SCHed:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:USER{userNull_cmd_val}:BWPart{bwPartNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:PTRS:TP:TMDensity?')
		return Conversions.str_to_scalar_enum(response, enums.PtrsTpTimeDensityAll)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PatternCls:
	"""Pattern commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pattern", core, parent)

	def set(self, pattern: str, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:SCRambler:PATTern \n
		Snippet: driver.source.bb.wlnn.fblock.user.scrambler.pattern.set(pattern = rawAbc, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		The command sets the initialization value for scrambling mode User. This value is then identical in each generated frame. \n
			:param pattern: 8 bits
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.value_to_str(pattern)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:SCRambler:PATTern {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:SCRambler:PATTern \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.user.scrambler.pattern.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		The command sets the initialization value for scrambling mode User. This value is then identical in each generated frame. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: pattern: 8 bits"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:SCRambler:PATTern?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QsControlCls:
	"""QsControl commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qsControl", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, qs_control: str, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:QSControl \n
		Snippet: driver.source.bb.wlnn.fblock.user.mac.qsControl.set(qs_control = rawAbc, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value for the QoS control field. \n
			:param qs_control: integer Range: #H0000,16 to #HFFFF,16
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.value_to_str(qs_control)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:QSControl {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:QSControl \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.user.mac.qsControl.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value for the QoS control field. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: qs_control: integer Range: #H0000,16 to #HFFFF,16"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:QSControl?')
		return trim_str_response(response)

	def clone(self) -> 'QsControlCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = QsControlCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.Cdma2KchanCoderType, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:CCODing:TYPE \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.ccoding.typePy.set(type_py = enums.Cdma2KchanCoderType.CON2, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command sets the channel coding type. This value is only available for channel coding modes 'Complete' and 'Without
		Interleaving' (SOURce:BB:C2K:BST<n>:CGRoup<n>:COFFset<n>:CCODing:MODE COMP | NOIN) . For the traffic channels, this value
		is specific for the selected radio configuration. \n
			:param type_py: CON2| CON3| CON4| CON6| TUR2| TUR3| TUR4| TUR5| OFF| DEFault NONE No error protection TURx Turbo Coder of rate 1/x in accordance with the CDMA specifications. CONx Convolution Coder of rate 1/x with generator polynomials defined by CDMA.
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.Cdma2KchanCoderType)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:CCODing:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> enums.Cdma2KchanCoderType:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:CCODing:TYPE \n
		Snippet: value: enums.Cdma2KchanCoderType = driver.source.bb.c2K.bstation.cgroup.coffset.ccoding.typePy.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command sets the channel coding type. This value is only available for channel coding modes 'Complete' and 'Without
		Interleaving' (SOURce:BB:C2K:BST<n>:CGRoup<n>:COFFset<n>:CCODing:MODE COMP | NOIN) . For the traffic channels, this value
		is specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: type_py: CON2| CON3| CON4| CON6| TUR2| TUR3| TUR4| TUR5| OFF| DEFault NONE No error protection TURx Turbo Coder of rate 1/x in accordance with the CDMA specifications. CONx Convolution Coder of rate 1/x with generator polynomials defined by CDMA."""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:CCODing:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.Cdma2KchanCoderType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UtypeCls:
	"""Utype commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("utype", core, parent)

	def set(self, utype: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:UTYPe \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.utype.set(utype = rawAbc, bitcount = 1) \n
		Enables that an invalid control packet is indicated. The CtrType field indicates the value of the LL control packet that
		caused the transmission of this packet. \n
			:param utype: numeric
			:param bitcount: integer Range: 8 to 8
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('utype', utype, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:UTYPe {param}'.rstrip())

	# noinspection PyTypeChecker
	class UtypeStruct(StructBase):
		"""Response structure. Fields: \n
			- Utype: str: numeric
			- Bitcount: int: integer Range: 8 to 8"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Utype'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Utype: str = None
			self.Bitcount: int = None

	def get(self) -> UtypeStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:UTYPe \n
		Snippet: value: UtypeStruct = driver.source.bb.btooth.econfiguration.pconfiguration.utype.get() \n
		Enables that an invalid control packet is indicated. The CtrType field indicates the value of the LL control packet that
		caused the transmission of this packet. \n
			:return: structure: for return value, see the help for UtypeStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:UTYPe?', self.__class__.UtypeStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.EvdoAckMode, terminal=repcap.Terminal.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:MODE \n
		Snippet: driver.source.bb.evdo.terminal.ackChannel.mode.set(mode = enums.EvdoAckMode.BPSK, terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Specifies the modulation mode of the ACK channel.
		With BPSK modulation, a 0 (ACK) is mapped to +1 and a 1 (NAK) to -1.With OOK modulation, a 0 (ACK) is mapped to ON and a
		1 (NAK) to OFF. \n
			:param mode: BPSK| OOK BPSK Sets the modulation to BPSK (Binary Phase Shift Keying) . OOK Sets the modulation to OOK (On-Off Keying) . Note: This value is only enabled for physical layer subtype 2.
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.EvdoAckMode)
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, terminal=repcap.Terminal.Default) -> enums.EvdoAckMode:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:MODE \n
		Snippet: value: enums.EvdoAckMode = driver.source.bb.evdo.terminal.ackChannel.mode.get(terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Specifies the modulation mode of the ACK channel.
		With BPSK modulation, a 0 (ACK) is mapped to +1 and a 1 (NAK) to -1.With OOK modulation, a 0 (ACK) is mapped to ON and a
		1 (NAK) to OFF. \n
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:return: mode: BPSK| OOK BPSK Sets the modulation to BPSK (Binary Phase Shift Keying) . OOK Sets the modulation to OOK (On-Off Keying) . Note: This value is only enabled for physical layer subtype 2."""
		terminal_cmd_val = self._cmd_group.get_repcap_cmd_value(terminal, repcap.Terminal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoAckMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrapezeCls:
	"""Trapeze commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trapeze", core, parent)

	@property
	def fall(self):
		"""fall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fall'):
			from .Fall import FallCls
			self._fall = FallCls(self._core, self._cmd_group)
		return self._fall

	@property
	def high(self):
		"""high commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_high'):
			from .High import HighCls
			self._high = HighCls(self._core, self._cmd_group)
		return self._high

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import PeriodCls
			self._period = PeriodCls(self._core, self._cmd_group)
		return self._period

	@property
	def rise(self):
		"""rise commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rise'):
			from .Rise import RiseCls
			self._rise = RiseCls(self._core, self._cmd_group)
		return self._rise

	def clone(self) -> 'TrapezeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TrapezeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConfCls:
	"""Conf commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("conf", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EutraPdschSchedMode:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CONF:MODE \n
		Snippet: value: enums.EutraPdschSchedMode = driver.source.bb.eutra.downlink.conf.get_mode() \n
		Determines how the scheduling of the different PDSCH allocations inside of the DL allocation table is performed. \n
			:return: scheduling: MANual| AUTO| ASEQuence MANual No cross-reference between the settings made for the PDCCH DCIs and the PDSCHs settings. Configure the PDSCH allocations manually. AUTO Precoding for spatial multiplexing according to and the selected parameters. ASEQuence According to the required HARQ processes and redundancy versions
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:CONF:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPdschSchedMode)

	def set_mode(self, scheduling: enums.EutraPdschSchedMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CONF:MODE \n
		Snippet: driver.source.bb.eutra.downlink.conf.set_mode(scheduling = enums.EutraPdschSchedMode.ASEQuence) \n
		Determines how the scheduling of the different PDSCH allocations inside of the DL allocation table is performed. \n
			:param scheduling: MANual| AUTO| ASEQuence MANual No cross-reference between the settings made for the PDCCH DCIs and the PDSCHs settings. Configure the PDSCH allocations manually. AUTO Precoding for spatial multiplexing according to and the selected parameters. ASEQuence According to the required HARQ processes and redundancy versions
		"""
		param = Conversions.enum_scalar_to_str(scheduling, enums.EutraPdschSchedMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CONF:MODE {param}')



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrsCls:
	"""Srs commands group definition. 33 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("srs", core, parent)

	@property
	def config(self):
		"""config commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_config'):
			from .Config import ConfigCls
			self._config = ConfigCls(self._core, self._cmd_group)
		return self._config

	@property
	def naPort(self):
		"""naPort commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_naPort'):
			from .NaPort import NaPortCls
			self._naPort = NaPortCls(self._core, self._cmd_group)
		return self._naPort

	@property
	def re02(self):
		"""re02 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_re02'):
			from .Re02 import Re02Cls
			self._re02 = Re02Cls(self._core, self._cmd_group)
		return self._re02

	@property
	def request(self):
		"""request commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_request'):
			from .Request import RequestCls
			self._request = RequestCls(self._core, self._cmd_group)
		return self._request

	@property
	def rs(self):
		"""rs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_rs'):
			from .Rs import RsCls
			self._rs = RsCls(self._core, self._cmd_group)
		return self._rs

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def clone(self) -> 'SrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TriggerCls:
	"""Trigger commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	def get_search(self) -> bool:
		"""SCPI: [SOURce<HW>]:[BB]:DME:PINPut:TRIGger:SEARch \n
		Snippet: value: bool = driver.source.bb.dme.pinput.trigger.get_search() \n
		Determines the trigger level that is the 50% voltage point of first pulse of the external DME interrogation signal.
		Determination of the trigger point requires a connected power sensor. Use a power sensor, for example the R&S NRP-Z81, to
		receive the external DME signal. Repeat the trigger search function when changing the level of the external DME signal. \n
			:return: search: 1| ON| 0| OFF 1|ON No trigger level found 0|OFF Trigger level found
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:PINPut:TRIGger:SEARch?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'TriggerCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TriggerCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IcaoCls:
	"""Icao commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("icao", core, parent)

	# noinspection PyTypeChecker
	def get_channel(self) -> enums.AvionicDmeIcaoChan:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ICAO:CHANnel \n
		Snippet: value: enums.AvionicDmeIcaoChan = driver.source.bb.dme.icao.get_channel() \n
		Sets the ICAO channel and the corresponding transmitting frequency. If avionic standard modulation is activated and you
		change the 'RF Frequency', the frequency value of the closest ICAO channel is applied automatically. The 'ICAO Channel'
		is also updated. The carrier frequency is set automatically to the value of the ICAO channel. For an overview of the DME
		ICAO channel frequencies, see Table 'DME ICAO channels and frequencies (MHz) '. \n
			:return: channel: CH1X| CH1Y| CH2X| CH2Y| CH3X| CH3Y| CH4X| CH4Y| CH5X| CH5Y| CH6X| CH6Y| CH7X| CH7Y| CH8X| CH8Y| CH9X| CH9Y| CH10X| CH10Y| CH11X| CH11Y| CH12X| CH12Y| CH13X| CH13Y| CH14X| CH14Y| CH15X| CH15Y| CH16X| CH16Y| CH17X| CH17Y| CH18X| CH18Y| CH19X| CH19Y| CH20X| CH20Y| CH21X| CH21Y| CH22X| CH22Y| CH23X| CH23Y| CH24X| CH24Y| CH25X| CH25Y| CH26X| CH26Y| CH27X| CH27Y| CH28X| CH28Y| CH29X| CH29Y| CH30X| CH30Y| CH31X| CH31Y| CH32X| CH32Y| CH33X| CH33Y| CH34X| CH34Y| CH35X| CH35Y| CH36X| CH36Y| CH37X| CH37Y| CH38X| CH38Y| CH39X| CH39Y| CH40X| CH40Y| CH41X| CH41Y| CH42X| CH42Y| CH43X| CH43Y| CH44X| CH44Y| CH45X| CH45Y| CH46X| CH46Y| CH47X| CH47Y| CH48X| CH48Y| CH49X| CH49Y| CH50X| CH50Y| CH51X| CH51Y| CH52X| CH52Y| CH53X| CH53Y| CH54X| CH54Y| CH55X| CH55Y| CH56X| CH56Y| CH57X| CH57Y| CH58X| CH58Y| CH59X| CH59Y| CH60X| CH60Y| CH61X| CH61Y| CH62X| CH62Y| CH63X| CH63Y| CH64X| CH64Y| CH65X| CH65Y| CH66X| CH66Y| CH67X| CH67Y| CH68X| CH68Y| CH69X| CH69Y| CH70X| CH70Y| CH71X| CH71Y| CH72X| CH72Y| CH73X| CH73Y| CH74X| CH74Y| CH75X| CH75Y| CH76X| CH76Y| CH77X| CH77Y| CH78X| CH78Y| CH79X| CH79Y| CH80X| CH80Y| CH81X| CH81Y| CH82X| CH82Y| CH83X| CH83Y| CH84X| CH84Y| CH85X| CH85Y| CH86X| CH86Y| CH87X| CH87Y| CH88X| CH88Y| CH89X| CH89Y| CH90X| CH90Y| CH91X| CH91Y| CH92X| CH92Y| CH93X| CH93Y| CH94X| CH94Y| CH95X| CH95Y| CH96X| CH96Y| CH97X| CH97Y| CH98X| CH98Y| CH99X| CH99Y| CH100X| CH100Y| CH101X| CH101Y| CH102X| CH102Y| CH103X| CH103Y| CH104X| CH104Y| CH105X| CH105Y| CH106X| CH106Y| CH107X| CH107Y| CH108X| CH108Y| CH109X| CH109Y| CH110X| CH110Y| CH111X| CH111Y| CH112X| CH112Y| CH113X| CH113Y| CH114X| CH114Y| CH115X| CH115Y| CH116X| CH116Y| CH117X| CH117Y| CH118X| CH118Y| CH119X| CH119Y| CH120X| CH120Y| CH121X| CH121Y| CH122X| CH122Y| CH123X| CH123Y| CH124X| CH124Y| CH125X| CH125Y| CH126X| CH126Y
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ICAO:CHANnel?')
		return Conversions.str_to_scalar_enum(response, enums.AvionicDmeIcaoChan)

	def set_channel(self, channel: enums.AvionicDmeIcaoChan) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ICAO:CHANnel \n
		Snippet: driver.source.bb.dme.icao.set_channel(channel = enums.AvionicDmeIcaoChan.CH100X) \n
		Sets the ICAO channel and the corresponding transmitting frequency. If avionic standard modulation is activated and you
		change the 'RF Frequency', the frequency value of the closest ICAO channel is applied automatically. The 'ICAO Channel'
		is also updated. The carrier frequency is set automatically to the value of the ICAO channel. For an overview of the DME
		ICAO channel frequencies, see Table 'DME ICAO channels and frequencies (MHz) '. \n
			:param channel: CH1X| CH1Y| CH2X| CH2Y| CH3X| CH3Y| CH4X| CH4Y| CH5X| CH5Y| CH6X| CH6Y| CH7X| CH7Y| CH8X| CH8Y| CH9X| CH9Y| CH10X| CH10Y| CH11X| CH11Y| CH12X| CH12Y| CH13X| CH13Y| CH14X| CH14Y| CH15X| CH15Y| CH16X| CH16Y| CH17X| CH17Y| CH18X| CH18Y| CH19X| CH19Y| CH20X| CH20Y| CH21X| CH21Y| CH22X| CH22Y| CH23X| CH23Y| CH24X| CH24Y| CH25X| CH25Y| CH26X| CH26Y| CH27X| CH27Y| CH28X| CH28Y| CH29X| CH29Y| CH30X| CH30Y| CH31X| CH31Y| CH32X| CH32Y| CH33X| CH33Y| CH34X| CH34Y| CH35X| CH35Y| CH36X| CH36Y| CH37X| CH37Y| CH38X| CH38Y| CH39X| CH39Y| CH40X| CH40Y| CH41X| CH41Y| CH42X| CH42Y| CH43X| CH43Y| CH44X| CH44Y| CH45X| CH45Y| CH46X| CH46Y| CH47X| CH47Y| CH48X| CH48Y| CH49X| CH49Y| CH50X| CH50Y| CH51X| CH51Y| CH52X| CH52Y| CH53X| CH53Y| CH54X| CH54Y| CH55X| CH55Y| CH56X| CH56Y| CH57X| CH57Y| CH58X| CH58Y| CH59X| CH59Y| CH60X| CH60Y| CH61X| CH61Y| CH62X| CH62Y| CH63X| CH63Y| CH64X| CH64Y| CH65X| CH65Y| CH66X| CH66Y| CH67X| CH67Y| CH68X| CH68Y| CH69X| CH69Y| CH70X| CH70Y| CH71X| CH71Y| CH72X| CH72Y| CH73X| CH73Y| CH74X| CH74Y| CH75X| CH75Y| CH76X| CH76Y| CH77X| CH77Y| CH78X| CH78Y| CH79X| CH79Y| CH80X| CH80Y| CH81X| CH81Y| CH82X| CH82Y| CH83X| CH83Y| CH84X| CH84Y| CH85X| CH85Y| CH86X| CH86Y| CH87X| CH87Y| CH88X| CH88Y| CH89X| CH89Y| CH90X| CH90Y| CH91X| CH91Y| CH92X| CH92Y| CH93X| CH93Y| CH94X| CH94Y| CH95X| CH95Y| CH96X| CH96Y| CH97X| CH97Y| CH98X| CH98Y| CH99X| CH99Y| CH100X| CH100Y| CH101X| CH101Y| CH102X| CH102Y| CH103X| CH103Y| CH104X| CH104Y| CH105X| CH105Y| CH106X| CH106Y| CH107X| CH107Y| CH108X| CH108Y| CH109X| CH109Y| CH110X| CH110Y| CH111X| CH111Y| CH112X| CH112Y| CH113X| CH113Y| CH114X| CH114Y| CH115X| CH115Y| CH116X| CH116Y| CH117X| CH117Y| CH118X| CH118Y| CH119X| CH119Y| CH120X| CH120Y| CH121X| CH121Y| CH122X| CH122Y| CH123X| CH123Y| CH124X| CH124Y| CH125X| CH125Y| CH126X| CH126Y
		"""
		param = Conversions.enum_scalar_to_str(channel, enums.AvionicDmeIcaoChan)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ICAO:CHANnel {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dselection(self):
		"""dselection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dselection'):
			from .Dselection import DselectionCls
			self._dselection = DselectionCls(self._core, self._cmd_group)
		return self._dselection

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	def set(self, data: enums.GbasDataSource, vdbTransmitter=repcap.VdbTransmitter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:DATA \n
		Snippet: driver.source.bb.gbas.vdb.data.set(data = enums.GbasDataSource.DLISt, vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Selects the data source, e.g. a sequence of 0 or 1, a pseudo-random sequence with different length, a pattern or a data
		list (DLISt) . \n
			:param data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| RGData
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
		"""
		param = Conversions.enum_scalar_to_str(data, enums.GbasDataSource)
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default) -> enums.GbasDataSource:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:DATA \n
		Snippet: value: enums.GbasDataSource = driver.source.bb.gbas.vdb.data.get(vdbTransmitter = repcap.VdbTransmitter.Default) \n
		Selects the data source, e.g. a sequence of 0 or 1, a pseudo-random sequence with different length, a pattern or a data
		list (DLISt) . \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:return: data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| RGData"""
		vdbTransmitter_cmd_val = self._cmd_group.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.GbasDataSource)

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpareUseCls:
	"""SpareUse commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spareUse", core, parent)

	def set(self, spatial_reuse: str, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:CINFo:SPAReuse \n
		Snippet: driver.source.bb.wlnn.fblock.user.tfConfig.cinfo.spareUse.set(spatial_reuse = rawAbc, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value bits of the common info field. \n
			:param spatial_reuse: 6 bits
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.value_to_str(spatial_reuse)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:CINFo:SPAReuse {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:TFConfig:CINFo:SPAReuse \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.user.tfConfig.cinfo.spareUse.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Sets the value bits of the common info field. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: spatial_reuse: No help available"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:TFConfig:CINFo:SPAReuse?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DetAttCls:
	"""DetAtt commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("detAtt", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.CalPowAmpDetMode:
		"""SCPI: CALibration:LEVel:DETatt:MODE \n
		Snippet: value: enums.CalPowAmpDetMode = driver.calibration.level.detAtt.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('CALibration:LEVel:DETatt:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.CalPowAmpDetMode)

	def set_mode(self, mode: enums.CalPowAmpDetMode) -> None:
		"""SCPI: CALibration:LEVel:DETatt:MODE \n
		Snippet: driver.calibration.level.detAtt.set_mode(mode = enums.CalPowAmpDetMode.AMP) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.CalPowAmpDetMode)
		self._core.io.write(f'CALibration:LEVel:DETatt:MODE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PulmCls:
	"""Pulm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pulm", core, parent)

	def get_level(self) -> float:
		"""SCPI: [SOURce]:INPut:USER:PULM:LEVel \n
		Snippet: value: float = driver.source.inputPy.user.pulm.get_level() \n
		Sets the threshold for any input signal at the User3-5 connectors. \n
			:return: level: float Range: 0.1 to 2, Unit: V
		"""
		response = self._core.io.query_str('SOURce:INPut:USER:PULM:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: [SOURce]:INPut:USER:PULM:LEVel \n
		Snippet: driver.source.inputPy.user.pulm.set_level(level = 1.0) \n
		Sets the threshold for any input signal at the User3-5 connectors. \n
			:param level: float Range: 0.1 to 2, Unit: V
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:INPut:USER:PULM:LEVel {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PlcchCls:
	"""Plcch commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("plcch", core, parent)

	@property
	def ssPattern(self):
		"""ssPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssPattern'):
			from .SsPattern import SsPatternCls
			self._ssPattern = SsPatternCls(self._core, self._cmd_group)
		return self._ssPattern

	@property
	def tpcPattern(self):
		"""tpcPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpcPattern'):
			from .TpcPattern import TpcPatternCls
			self._tpcPattern = TpcPatternCls(self._core, self._cmd_group)
		return self._tpcPattern

	@property
	def ttInterval(self):
		"""ttInterval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttInterval'):
			from .TtInterval import TtIntervalCls
			self._ttInterval = TtIntervalCls(self._core, self._cmd_group)
		return self._ttInterval

	def clone(self) -> 'PlcchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PlcchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LocalizerCls:
	"""Localizer commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("localizer", core, parent)

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:ILS:LOCalizer:PRESet \n
		Snippet: driver.source.ils.localizer.preset() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:ILS:LOCalizer:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:ILS:LOCalizer:PRESet \n
		Snippet: driver.source.ils.localizer.preset_with_opc() \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:ILS:LOCalizer:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:ILS:LOCalizer:STATe \n
		Snippet: value: bool = driver.source.ils.localizer.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:ILS:LOCalizer:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:ILS:LOCalizer:STATe \n
		Snippet: driver.source.ils.localizer.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:ILS:LOCalizer:STATe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TargetCls:
	"""Target commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("target", core, parent)

	def set(self, cw_freq_offset: float, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:AWGN:[RF<CH>]:FREQuency:TARGet \n
		Snippet: driver.source.bb.gnss.awgn.rf.frequency.target.set(cw_freq_offset = 1.0, path = repcap.Path.Default) \n
		Sets the frequency offset of the sine wave relative to the 'Reference Frequency'. \n
			:param cw_freq_offset: float Range: -250E6 to 250E6
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
		"""
		param = Conversions.decimal_value_to_str(cw_freq_offset)
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:AWGN:RF{path_cmd_val}:FREQuency:TARGet {param}')

	def get(self, path=repcap.Path.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:AWGN:[RF<CH>]:FREQuency:TARGet \n
		Snippet: value: float = driver.source.bb.gnss.awgn.rf.frequency.target.get(path = repcap.Path.Default) \n
		Sets the frequency offset of the sine wave relative to the 'Reference Frequency'. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:return: cw_freq_offset: float Range: -250E6 to 250E6"""
		path_cmd_val = self._cmd_group.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:AWGN:RF{path_cmd_val}:FREQuency:TARGet?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class S30KCls:
	"""S30K commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("s30K", core, parent)

	@property
	def komu(self):
		"""komu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_komu'):
			from .Komu import KomuCls
			self._komu = KomuCls(self._core, self._cmd_group)
		return self._komu

	@property
	def nrb(self):
		"""nrb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nrb'):
			from .Nrb import NrbCls
			self._nrb = NrbCls(self._core, self._cmd_group)
		return self._nrb

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def use(self):
		"""use commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_use'):
			from .Use import UseCls
			self._use = UseCls(self._core, self._cmd_group)
		return self._use

	def clone(self) -> 'S30KCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = S30KCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EcodeCls:
	"""Ecode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ecode", core, parent)

	def set(self, ecode: str, bitcount: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:CDATa:ECODe \n
		Snippet: driver.source.bb.btooth.cs.cdata.ecode.set(ecode = rawAbc, bitcount = 1) \n
		No command help available \n
			:param ecode: No help available
			:param bitcount: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('ecode', ecode, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:CS:CDATa:ECODe {param}'.rstrip())

	# noinspection PyTypeChecker
	class EcodeStruct(StructBase):
		"""Response structure. Fields: \n
			- Ecode: str: No parameter help available
			- Bitcount: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Ecode'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Ecode: str = None
			self.Bitcount: int = None

	def get(self) -> EcodeStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:CS:CDATa:ECODe \n
		Snippet: value: EcodeStruct = driver.source.bb.btooth.cs.cdata.ecode.get() \n
		No command help available \n
			:return: structure: for return value, see the help for EcodeStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:BTOoth:CS:CDATa:ECODe?', self.__class__.EcodeStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GateCls:
	"""Gate commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gate", core, parent)

	def get_edelay(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:EDELay \n
		Snippet: value: float = driver.source.bb.dme.analysis.gate.get_edelay() \n
		Sets the expected reply delay. The expected reply delay and the gate length determine the measurement window (expected
		reply delay +/- gate length/2) . \n
			:return: edelay: float Range: 0 to 150E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ANALysis:GATE:EDELay?')
		return Conversions.str_to_float(response)

	def set_edelay(self, edelay: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:EDELay \n
		Snippet: driver.source.bb.dme.analysis.gate.set_edelay(edelay = 1.0) \n
		Sets the expected reply delay. The expected reply delay and the gate length determine the measurement window (expected
		reply delay +/- gate length/2) . \n
			:param edelay: float Range: 0 to 150E-6
		"""
		param = Conversions.decimal_value_to_str(edelay)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ANALysis:GATE:EDELay {param}')

	def get_time(self) -> float:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:TIME \n
		Snippet: value: float = driver.source.bb.dme.analysis.gate.get_time() \n
		Sets the DME analysis measurement time. \n
			:return: measurement_time: float Range: 0.1 to 20
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ANALysis:GATE:TIME?')
		return Conversions.str_to_float(response)

	def set_time(self, measurement_time: float) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:TIME \n
		Snippet: driver.source.bb.dme.analysis.gate.set_time(measurement_time = 1.0) \n
		Sets the DME analysis measurement time. \n
			:param measurement_time: float Range: 0.1 to 20
		"""
		param = Conversions.decimal_value_to_str(measurement_time)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ANALysis:GATE:TIME {param}')

	def get_length(self) -> int:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:[LENGth] \n
		Snippet: value: int = driver.source.bb.dme.analysis.gate.get_length() \n
		Sets the gate length for the measurement window. The measurement gate settings determine the measurement window (expected
		reply delay +/- gate length/2) . Only reply pulses for which the 50% voltage point of the rising edge of the first pulse
		is within the measurement window are used to evaluate the delay time and reply efficiency. The delay measurement is
		averaged within the measurement cycle. The reply efficiency is calculated once for each measurement cycle.
		The gate length is 1 us and the expected reply delay is 50 us. The measurement window lies in the range between 49.5 and
		50.5 us. Only pulse pairs are used for the measurement whose 50% voltage point of the rising edge of the first pulse is
		within this range. \n
			:return: length: integer Range: 100E-9 to 326E-6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DME:ANALysis:GATE:LENGth?')
		return Conversions.str_to_int(response)

	def set_length(self, length: int) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:ANALysis:GATE:[LENGth] \n
		Snippet: driver.source.bb.dme.analysis.gate.set_length(length = 1) \n
		Sets the gate length for the measurement window. The measurement gate settings determine the measurement window (expected
		reply delay +/- gate length/2) . Only reply pulses for which the 50% voltage point of the rising edge of the first pulse
		is within the measurement window are used to evaluate the delay time and reply efficiency. The delay measurement is
		averaged within the measurement cycle. The reply efficiency is calculated once for each measurement cycle.
		The gate length is 1 us and the expected reply delay is 50 us. The measurement window lies in the range between 49.5 and
		50.5 us. Only pulse pairs are used for the measurement whose 50% voltage point of the rising edge of the first pulse is
		within this range. \n
			:param length: integer Range: 100E-9 to 326E-6
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:ANALysis:GATE:LENGth {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TgdCls:
	"""Tgd commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tgd", core, parent)

	def set(self, tgd: int, mobileStation=repcap.MobileStation.Default, patternIx=repcap.PatternIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CMODe:PATTern<CH>:TGD \n
		Snippet: driver.source.bb.w3Gpp.mstation.cmode.pattern.tgd.set(tgd = 1, mobileStation = repcap.MobileStation.Default, patternIx = repcap.PatternIx.Default) \n
		Sets the transmission gap distances. \n
			:param tgd: integer Range: 3 to 100
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param patternIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pattern')
		"""
		param = Conversions.decimal_value_to_str(tgd)
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		patternIx_cmd_val = self._cmd_group.get_repcap_cmd_value(patternIx, repcap.PatternIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CMODe:PATTern{patternIx_cmd_val}:TGD {param}')

	def get(self, mobileStation=repcap.MobileStation.Default, patternIx=repcap.PatternIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:CMODe:PATTern<CH>:TGD \n
		Snippet: value: int = driver.source.bb.w3Gpp.mstation.cmode.pattern.tgd.get(mobileStation = repcap.MobileStation.Default, patternIx = repcap.PatternIx.Default) \n
		Sets the transmission gap distances. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param patternIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pattern')
			:return: tgd: integer Range: 3 to 100"""
		mobileStation_cmd_val = self._cmd_group.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		patternIx_cmd_val = self._cmd_group.get_repcap_cmd_value(patternIx, repcap.PatternIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:CMODe:PATTern{patternIx_cmd_val}:TGD?')
		return Conversions.str_to_int(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrecInfoCls:
	"""PrecInfo commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("precInfo", core, parent)

	def set(self, precoding_info: int, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:PRECinfo \n
		Snippet: driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.precInfo.set(precoding_info = 1, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 2/2A field Precoding Information. \n
			:param precoding_info: integer Range: 0 to 63
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
		"""
		param = Conversions.decimal_value_to_str(precoding_info)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._cmd_group.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:PRECinfo {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:PRECinfo \n
		Snippet: value: int = driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.precInfo.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 2/2A field Precoding Information. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: precoding_info: integer Range: 0 to 63"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._cmd_group.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:PRECinfo?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AntCls:
	"""Ant commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ant", core, parent)

	# noinspection PyTypeChecker
	def get_rx_antennas(self) -> enums.RxaNt:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:ANT:RXANtennas \n
		Snippet: value: enums.RxaNt = driver.source.bb.nr5G.tcw.ant.get_rx_antennas() \n
		Shows or sets the number of Rx antennas used for test case. \n
			:return: rx_antennas: ANT1| ANT2| ANT4| ANT8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:ANT:RXANtennas?')
		return Conversions.str_to_scalar_enum(response, enums.RxaNt)

	def set_rx_antennas(self, rx_antennas: enums.RxaNt) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:ANT:RXANtennas \n
		Snippet: driver.source.bb.nr5G.tcw.ant.set_rx_antennas(rx_antennas = enums.RxaNt.ANT1) \n
		Shows or sets the number of Rx antennas used for test case. \n
			:param rx_antennas: ANT1| ANT2| ANT4| ANT8
		"""
		param = Conversions.enum_scalar_to_str(rx_antennas, enums.RxaNt)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:ANT:RXANtennas {param}')

	# noinspection PyTypeChecker
	def get_tx_antennas(self) -> enums.TxAntenna:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:ANT:TXANtennas \n
		Snippet: value: enums.TxAntenna = driver.source.bb.nr5G.tcw.ant.get_tx_antennas() \n
		Shows or sets the number of Tx antennas used for test case. \n
			:return: tx_antennas: ANT1| ANT2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:ANT:TXANtennas?')
		return Conversions.str_to_scalar_enum(response, enums.TxAntenna)

	def set_tx_antennas(self, tx_antennas: enums.TxAntenna) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:ANT:TXANtennas \n
		Snippet: driver.source.bb.nr5G.tcw.ant.set_tx_antennas(tx_antennas = enums.TxAntenna.ANT1) \n
		Shows or sets the number of Tx antennas used for test case. \n
			:param tx_antennas: ANT1| ANT2
		"""
		param = Conversions.enum_scalar_to_str(tx_antennas, enums.TxAntenna)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:ANT:TXANtennas {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dselection(self):
		"""dselection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dselection'):
			from .Dselection import DselectionCls
			self._dselection = DselectionCls(self._core, self._cmd_group)
		return self._dselection

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import PatternCls
			self._pattern = PatternCls(self._core, self._cmd_group)
		return self._pattern

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_source'):
			from .Source import SourceCls
			self._source = SourceCls(self._core, self._cmd_group)
		return self._source

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModCls:
	"""Mod commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mod", core, parent)

	def set(self, mode: enums.IdEutraNbiotMode, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:PRACh:NIOT:MOD \n
		Snippet: driver.source.bb.eutra.uplink.ue.prach.niot.mod.set(mode = enums.IdEutraNbiotMode.ALON, userEquipment = repcap.UserEquipment.Default) \n
		Selects the operating mode. \n
			:param mode: INBD| ALON| GBD
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.IdEutraNbiotMode)
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:PRACh:NIOT:MOD {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default) -> enums.IdEutraNbiotMode:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:PRACh:NIOT:MOD \n
		Snippet: value: enums.IdEutraNbiotMode = driver.source.bb.eutra.uplink.ue.prach.niot.mod.get(userEquipment = repcap.UserEquipment.Default) \n
		Selects the operating mode. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: mode: INBD| ALON| GBD"""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:PRACh:NIOT:MOD?')
		return Conversions.str_to_scalar_enum(response, enums.IdEutraNbiotMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AtmosphericCls:
	"""Atmospheric commands group definition. 71 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("atmospheric", core, parent)

	@property
	def beidou(self):
		"""beidou commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_beidou'):
			from .Beidou import BeidouCls
			self._beidou = BeidouCls(self._core, self._cmd_group)
		return self._beidou

	@property
	def galileo(self):
		"""galileo commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_galileo'):
			from .Galileo import GalileoCls
			self._galileo = GalileoCls(self._core, self._cmd_group)
		return self._galileo

	@property
	def gps(self):
		"""gps commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_gps'):
			from .Gps import GpsCls
			self._gps = GpsCls(self._core, self._cmd_group)
		return self._gps

	@property
	def ionospheric(self):
		"""ionospheric commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_ionospheric'):
			from .Ionospheric import IonosphericCls
			self._ionospheric = IonosphericCls(self._core, self._cmd_group)
		return self._ionospheric

	@property
	def navic(self):
		"""navic commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_navic'):
			from .Navic import NavicCls
			self._navic = NavicCls(self._core, self._cmd_group)
		return self._navic

	@property
	def qzss(self):
		"""qzss commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_qzss'):
			from .Qzss import QzssCls
			self._qzss = QzssCls(self._core, self._cmd_group)
		return self._qzss

	@property
	def tropospheric(self):
		"""tropospheric commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tropospheric'):
			from .Tropospheric import TroposphericCls
			self._tropospheric = TroposphericCls(self._core, self._cmd_group)
		return self._tropospheric

	def clone(self) -> 'AtmosphericCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AtmosphericCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DelayCls:
	"""Delay commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("delay", core, parent)

	def set(self, delay: int, marker=repcap.Marker.Default) -> None:
		"""SCPI: [SOURce<HW>]:[BB]:DME:MARKer<CH>:DELay \n
		Snippet: driver.source.bb.dme.marker.delay.set(delay = 1, marker = repcap.Marker.Default) \n
		Sets the delay between the marker signal at the marker outputs relative to the signal generation start. \n
			:param delay: integer Range: 0 to 127
			:param marker: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Marker')
		"""
		param = Conversions.decimal_value_to_str(delay)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'SOURce<HwInstance>:BB:DME:MARKer{marker_cmd_val}:DELay {param}')

	def get(self, marker=repcap.Marker.Default) -> int:
		"""SCPI: [SOURce<HW>]:[BB]:DME:MARKer<CH>:DELay \n
		Snippet: value: int = driver.source.bb.dme.marker.delay.get(marker = repcap.Marker.Default) \n
		Sets the delay between the marker signal at the marker outputs relative to the signal generation start. \n
			:param marker: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Marker')
			:return: delay: integer Range: 0 to 127"""
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:DME:MARKer{marker_cmd_val}:DELay?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ApmCls:
	"""Apm commands group definition. 7 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("apm", core, parent)

	@property
	def cbci(self):
		"""cbci commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbci'):
			from .Cbci import CbciCls
			self._cbci = CbciCls(self._core, self._cmd_group)
		return self._cbci

	@property
	def cbIndex(self):
		"""cbIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbIndex'):
			from .CbIndex import CbIndexCls
			self._cbIndex = CbIndexCls(self._core, self._cmd_group)
		return self._cbIndex

	@property
	def cbua(self):
		"""cbua commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbua'):
			from .Cbua import CbuaCls
			self._cbua = CbuaCls(self._core, self._cmd_group)
		return self._cbua

	@property
	def mapCoordinates(self):
		"""mapCoordinates commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mapCoordinates'):
			from .MapCoordinates import MapCoordinatesCls
			self._mapCoordinates = MapCoordinatesCls(self._core, self._cmd_group)
		return self._mapCoordinates

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def layer(self):
		"""layer commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_layer'):
			from .Layer import LayerCls
			self._layer = LayerCls(self._core, self._cmd_group)
		return self._layer

	def clone(self) -> 'ApmCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ApmCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, tbs_alt_index_old: bool, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:TALTindex:STATe \n
		Snippet: driver.source.bb.eutra.downlink.user.taltIndex.state.set(tbs_alt_index_old = False, userIx = repcap.UserIx.Default) \n
		This command is supported for backwards compatibility. Use [:SOURce<hw>]:BB:EUTRa:DL:USER<ch>:CELL<st0>:TBAL instead. \n
			:param tbs_alt_index_old: 1| ON| 0| OFF
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.bool_to_str(tbs_alt_index_old)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:TALTindex:STATe {param}')

	def get(self, userIx=repcap.UserIx.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:TALTindex:STATe \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.user.taltIndex.state.get(userIx = repcap.UserIx.Default) \n
		This command is supported for backwards compatibility. Use [:SOURce<hw>]:BB:EUTRa:DL:USER<ch>:CELL<st0>:TBAL instead. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: tbs_alt_index_old: 1| ON| 0| OFF"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{userIx_cmd_val}:TALTindex:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RtfCls:
	"""Rtf commands group definition. 10 total commands, 0 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rtf", core, parent)

	# noinspection PyTypeChecker
	def get_ack_definition(self) -> enums.LowHigh:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:ACKDefinition \n
		Snippet: value: enums.LowHigh = driver.source.bb.eutra.tcw.rtf.get_ack_definition() \n
		No command help available \n
			:return: ack_definition: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:ACKDefinition?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)

	def set_ack_definition(self, ack_definition: enums.LowHigh) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:ACKDefinition \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_ack_definition(ack_definition = enums.LowHigh.HIGH) \n
		No command help available \n
			:param ack_definition: No help available
		"""
		param = Conversions.enum_scalar_to_str(ack_definition, enums.LowHigh)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:ACKDefinition {param}')

	def get_aus_delay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:AUSDelay \n
		Snippet: value: float = driver.source.bb.eutra.tcw.rtf.get_aus_delay() \n
		No command help available \n
			:return: add_user_delay: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:AUSDelay?')
		return Conversions.str_to_float(response)

	def set_aus_delay(self, add_user_delay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:AUSDelay \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_aus_delay(add_user_delay = 1.0) \n
		No command help available \n
			:param add_user_delay: No help available
		"""
		param = Conversions.decimal_value_to_str(add_user_delay)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:AUSDelay {param}')

	def get_bb_smue(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSMue \n
		Snippet: value: int = driver.source.bb.eutra.tcw.rtf.get_bb_smue() \n
		No command help available \n
			:return: bb_select_mov_ue: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSMue?')
		return Conversions.str_to_int(response)

	def set_bb_smue(self, bb_select_mov_ue: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSMue \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_bb_smue(bb_select_mov_ue = 1) \n
		No command help available \n
			:param bb_select_mov_ue: No help available
		"""
		param = Conversions.decimal_value_to_str(bb_select_mov_ue)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSMue {param}')

	def get_bb_ssue(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSSue \n
		Snippet: value: int = driver.source.bb.eutra.tcw.rtf.get_bb_ssue() \n
		No command help available \n
			:return: bb_select_stat_ue: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSSue?')
		return Conversions.str_to_int(response)

	def set_bb_ssue(self, bb_select_stat_ue: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSSue \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_bb_ssue(bb_select_stat_ue = 1) \n
		No command help available \n
			:param bb_select_stat_ue: No help available
		"""
		param = Conversions.decimal_value_to_str(bb_select_stat_ue)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSSue {param}')

	def get_bb_selector(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSelector \n
		Snippet: value: int = driver.source.bb.eutra.tcw.rtf.get_bb_selector() \n
		No command help available \n
			:return: bb_selector: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSelector?')
		return Conversions.str_to_int(response)

	def set_bb_selector(self, bb_selector: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:BBSelector \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_bb_selector(bb_selector = 1) \n
		No command help available \n
			:param bb_selector: No help available
		"""
		param = Conversions.decimal_value_to_str(bb_selector)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:BBSelector {param}')

	# noinspection PyTypeChecker
	def get_conmue(self) -> enums.EutraTcwConnector:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONMue \n
		Snippet: value: enums.EutraTcwConnector = driver.source.bb.eutra.tcw.rtf.get_conmue() \n
		No command help available \n
			:return: connector_mov_ue: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONMue?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwConnector)

	def set_conmue(self, connector_mov_ue: enums.EutraTcwConnector) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONMue \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_conmue(connector_mov_ue = enums.EutraTcwConnector.LEVatt) \n
		No command help available \n
			:param connector_mov_ue: No help available
		"""
		param = Conversions.enum_scalar_to_str(connector_mov_ue, enums.EutraTcwConnector)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONMue {param}')

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.EutraTcwConnector:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONNector \n
		Snippet: value: enums.EutraTcwConnector = driver.source.bb.eutra.tcw.rtf.get_connector() \n
		No command help available \n
			:return: connector: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwConnector)

	def set_connector(self, connector: enums.EutraTcwConnector) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONNector \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_connector(connector = enums.EutraTcwConnector.LEVatt) \n
		No command help available \n
			:param connector: No help available
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.EutraTcwConnector)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONNector {param}')

	# noinspection PyTypeChecker
	def get_consue(self) -> enums.EutraTcwConnector:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONSue \n
		Snippet: value: enums.EutraTcwConnector = driver.source.bb.eutra.tcw.rtf.get_consue() \n
		No command help available \n
			:return: connector_stat_ue: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONSue?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwConnector)

	def set_consue(self, connector_stat_ue: enums.EutraTcwConnector) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:CONSue \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_consue(connector_stat_ue = enums.EutraTcwConnector.LEVatt) \n
		No command help available \n
			:param connector_stat_ue: No help available
		"""
		param = Conversions.enum_scalar_to_str(connector_stat_ue, enums.EutraTcwConnector)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:CONSue {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EutraTcwrtfMode:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:MODE \n
		Snippet: value: enums.EutraTcwrtfMode = driver.source.bb.eutra.tcw.rtf.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwrtfMode)

	def set_mode(self, mode: enums.EutraTcwrtfMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:MODE \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_mode(mode = enums.EutraTcwrtfMode.BIN) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.EutraTcwrtfMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:MODE {param}')

	# noinspection PyTypeChecker
	def get_ser_rate(self) -> enums.EutraSerialRate:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:SERRate \n
		Snippet: value: enums.EutraSerialRate = driver.source.bb.eutra.tcw.rtf.get_ser_rate() \n
		No command help available \n
			:return: serial_rate: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:RTF:SERRate?')
		return Conversions.str_to_scalar_enum(response, enums.EutraSerialRate)

	def set_ser_rate(self, serial_rate: enums.EutraSerialRate) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:RTF:SERRate \n
		Snippet: driver.source.bb.eutra.tcw.rtf.set_ser_rate(serial_rate = enums.EutraSerialRate.SR1_6M) \n
		No command help available \n
			:param serial_rate: No help available
		"""
		param = Conversions.enum_scalar_to_str(serial_rate, enums.EutraSerialRate)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:RTF:SERRate {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GslopeCls:
	"""Gslope commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gslope", core, parent)

	@property
	def ddm(self):
		"""ddm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ddm'):
			from .Ddm import DdmCls
			self._ddm = DdmCls(self._core, self._cmd_group)
		return self._ddm

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:ILS:GSLope:PRESet \n
		Snippet: driver.source.ils.gslope.preset() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:ILS:GSLope:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:ILS:GSLope:PRESet \n
		Snippet: driver.source.ils.gslope.preset_with_opc() \n
		No command help available \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:ILS:GSLope:PRESet', opc_timeout_ms)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:ILS:GSLope:STATe \n
		Snippet: value: bool = driver.source.ils.gslope.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:ILS:GSLope:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:ILS:GSLope:STATe \n
		Snippet: driver.source.ils.gslope.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:ILS:GSLope:STATe {param}')

	def clone(self) -> 'GslopeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GslopeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def get(self, baseStation=repcap.BaseStation.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:DCONflict:[STATe] \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.dconflict.state.get(baseStation = repcap.BaseStation.Default) \n
		The command queries whether there is (response 1) or is not (response 0) a conflict (overlap) in the
		hierarchically-structured channelization codes. The cause of a possible domain conflict can be ascertained by manual
		operation in the 'BS > Code Domain' dialog. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:return: state: 1| ON| 0| OFF"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:DCONflict:STATe?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DurationCls:
	"""Duration commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("duration", core, parent)

	# noinspection PyTypeChecker
	def get_coefficent(self) -> enums.EutraNbiotGapDurationCoefficent:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:GAP:DURation:COEFficent \n
		Snippet: value: enums.EutraNbiotGapDurationCoefficent = driver.source.bb.eutra.downlink.niot.gap.duration.get_coefficent() \n
		Sets the gap duration coefficient. \n
			:return: gap_dur_coeff: 1_8| 1_4| 3_8| 1_2
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:NIOT:GAP:DURation:COEFficent?')
		return Conversions.str_to_scalar_enum(response, enums.EutraNbiotGapDurationCoefficent)

	def set_coefficent(self, gap_dur_coeff: enums.EutraNbiotGapDurationCoefficent) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:NIOT:GAP:DURation:COEFficent \n
		Snippet: driver.source.bb.eutra.downlink.niot.gap.duration.set_coefficent(gap_dur_coeff = enums.EutraNbiotGapDurationCoefficent._1_2) \n
		Sets the gap duration coefficient. \n
			:param gap_dur_coeff: 1_8| 1_4| 3_8| 1_2
		"""
		param = Conversions.enum_scalar_to_str(gap_dur_coeff, enums.EutraNbiotGapDurationCoefficent)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:NIOT:GAP:DURation:COEFficent {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UfmcCls:
	"""Ufmc commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ufmc", core, parent)

	def get_nsuband(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:OFDM:UFMC:NSUBand \n
		Snippet: value: int = driver.source.bb.ofdm.ufmc.get_nsuband() \n
		Sets the number of UFMC subbands. \n
			:return: nsubbands: integer Range: 1 to 1500
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:UFMC:NSUBand?')
		return Conversions.str_to_int(response)

	def set_nsuband(self, nsubbands: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:UFMC:NSUBand \n
		Snippet: driver.source.bb.ofdm.ufmc.set_nsuband(nsubbands = 1) \n
		Sets the number of UFMC subbands. \n
			:param nsubbands: integer Range: 1 to 1500
		"""
		param = Conversions.decimal_value_to_str(nsubbands)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:UFMC:NSUBand {param}')

	def get_pre_equal(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:OFDM:UFMC:PREequal \n
		Snippet: value: bool = driver.source.bb.ofdm.ufmc.get_pre_equal() \n
		Applies a filter pre-equalization. \n
			:return: ufmc_pre_equal: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:OFDM:UFMC:PREequal?')
		return Conversions.str_to_bool(response)

	def set_pre_equal(self, ufmc_pre_equal: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:OFDM:UFMC:PREequal \n
		Snippet: driver.source.bb.ofdm.ufmc.set_pre_equal(ufmc_pre_equal = False) \n
		Applies a filter pre-equalization. \n
			:param ufmc_pre_equal: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(ufmc_pre_equal)
		self._core.io.write(f'SOURce<HwInstance>:BB:OFDM:UFMC:PREequal {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.Cdma2KdomConfModeDn, baseStation=repcap.BaseStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:DCONflict:MODE \n
		Snippet: driver.source.bb.c2K.bstation.dconflict.mode.set(mode = enums.Cdma2KdomConfModeDn.BREV, baseStation = repcap.BaseStation.Default) \n
		The command switches the order of the spreading codes. \n
			:param mode: HAD| BREV HAD the code channels are displayed in the order determined by the Hadamard matrix. The codes are numbered as Walsh codes according to the standard. BREV the code channels are displayed in the order defined by the Orthogonal Variable Spreading Factor (OVSF) code tree (3GPP code) .
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.Cdma2KdomConfModeDn)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:DCONflict:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default) -> enums.Cdma2KdomConfModeDn:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:DCONflict:MODE \n
		Snippet: value: enums.Cdma2KdomConfModeDn = driver.source.bb.c2K.bstation.dconflict.mode.get(baseStation = repcap.BaseStation.Default) \n
		The command switches the order of the spreading codes. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:return: mode: HAD| BREV HAD the code channels are displayed in the order determined by the Hadamard matrix. The codes are numbered as Walsh codes according to the standard. BREV the code channels are displayed in the order defined by the Orthogonal Variable Spreading Factor (OVSF) code tree (3GPP code) ."""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:DCONflict:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.Cdma2KdomConfModeDn)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScodeCls:
	"""Scode commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scode", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, scode: int, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:SCODe \n
		Snippet: driver.source.bb.tdscdma.up.cell.scode.set(scode = 1, cell = repcap.Cell.Default) \n
		Sets the scrambling code. The scrambling code is used for transmitter-dependent scrambling of the chip sequence. \n
			:param scode: integer Range: 0 to 127
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
		"""
		param = Conversions.decimal_value_to_str(scode)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:SCODe {param}')

	def get(self, cell=repcap.Cell.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:SCODe \n
		Snippet: value: int = driver.source.bb.tdscdma.up.cell.scode.get(cell = repcap.Cell.Default) \n
		Sets the scrambling code. The scrambling code is used for transmitter-dependent scrambling of the chip sequence. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: scode: integer Range: 0 to 127"""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:SCODe?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'ScodeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScodeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PeriodCls:
	"""Period commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("period", core, parent)

	def set(self, period: enums.EvdoDrcPer, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:DRCLock:PERiod \n
		Snippet: driver.source.bb.evdo.user.drclock.period.set(period = enums.EvdoDrcPer.DP0, userIx = repcap.UserIx.Default) \n
		Sets the period (measured in slots) of time between successive transmissions of the DRC (Data Rate Control) Lock bit for
		the selected user. Note: A value of zero disables the DRC Lock subchannel and the MAC RPC channel of the selected user is
		not punctured with the DRC Lock subchannel. \n
			:param period: DP0| DP4| DP8| DP16
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(period, enums.EvdoDrcPer)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:DRCLock:PERiod {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.EvdoDrcPer:
		"""SCPI: [SOURce<HW>]:BB:EVDO:USER<ST>:DRCLock:PERiod \n
		Snippet: value: enums.EvdoDrcPer = driver.source.bb.evdo.user.drclock.period.get(userIx = repcap.UserIx.Default) \n
		Sets the period (measured in slots) of time between successive transmissions of the DRC (Data Rate Control) Lock bit for
		the selected user. Note: A value of zero disables the DRC Lock subchannel and the MAC RPC channel of the selected user is
		not punctured with the DRC Lock subchannel. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: period: DP0| DP4| DP8| DP16"""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:USER{userIx_cmd_val}:DRCLock:PERiod?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoDrcPer)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, offset: float, offsetNull=repcap.OffsetNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:OFFSet<CH0>:VALue \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.offset.value.set(offset = 1.0, offsetNull = repcap.OffsetNull.Default) \n
		Specifies Offset0 to Offset5 of the offset setting table. Command sets the values in ms. Query returns values in s. \n
			:param offset: float Range: 0 s to depending on Max. Interval , Unit: ms
			:param offsetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Offset')
		"""
		param = Conversions.decimal_value_to_str(offset)
		offsetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(offsetNull, repcap.OffsetNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:OFFSet{offsetNull_cmd_val}:VALue {param}')

	def get(self, offsetNull=repcap.OffsetNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:OFFSet<CH0>:VALue \n
		Snippet: value: float = driver.source.bb.btooth.econfiguration.pconfiguration.offset.value.get(offsetNull = repcap.OffsetNull.Default) \n
		Specifies Offset0 to Offset5 of the offset setting table. Command sets the values in ms. Query returns values in s. \n
			:param offsetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Offset')
			:return: offset: float Range: 0 s to depending on Max. Interval , Unit: ms"""
		offsetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(offsetNull, repcap.OffsetNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:OFFSet{offsetNull_cmd_val}:VALue?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviationCls:
	"""Deviation commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("deviation", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ModulationDevMode:
		"""SCPI: [SOURce<HW>]:FM:DEViation:MODE \n
		Snippet: value: enums.ModulationDevMode = driver.source.fm.deviation.get_mode() \n
		Selects the coupling mode. The coupling mode parameter also determines the mode for fixing the total deviation. \n
			:return: fm_dev_mode: UNCoupled| TOTal| RATio UNCoupled Does not couple the LF signals. The deviation values of both paths are independent. TOTal Couples the deviation of both paths. RATio Couples the deviation ratio of both paths
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FM:DEViation:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationDevMode)

	def set_mode(self, fm_dev_mode: enums.ModulationDevMode) -> None:
		"""SCPI: [SOURce<HW>]:FM:DEViation:MODE \n
		Snippet: driver.source.fm.deviation.set_mode(fm_dev_mode = enums.ModulationDevMode.RATio) \n
		Selects the coupling mode. The coupling mode parameter also determines the mode for fixing the total deviation. \n
			:param fm_dev_mode: UNCoupled| TOTal| RATio UNCoupled Does not couple the LF signals. The deviation values of both paths are independent. TOTal Couples the deviation of both paths. RATio Couples the deviation ratio of both paths
		"""
		param = Conversions.enum_scalar_to_str(fm_dev_mode, enums.ModulationDevMode)
		self._core.io.write(f'SOURce<HwInstance>:FM:DEViation:MODE {param}')

	def get_sum(self) -> float:
		"""SCPI: [SOURce<HW>]:FM:DEViation:SUM \n
		Snippet: value: float = driver.source.fm.deviation.get_sum() \n
		Sets the total deviation of the LF signal when using combined signal sources in frequency modulation. \n
			:return: fm_dev_sum: float Range: 0 to 40E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FM:DEViation:SUM?')
		return Conversions.str_to_float(response)

	def set_sum(self, fm_dev_sum: float) -> None:
		"""SCPI: [SOURce<HW>]:FM:DEViation:SUM \n
		Snippet: driver.source.fm.deviation.set_sum(fm_dev_sum = 1.0) \n
		Sets the total deviation of the LF signal when using combined signal sources in frequency modulation. \n
			:param fm_dev_sum: float Range: 0 to 40E6
		"""
		param = Conversions.decimal_value_to_str(fm_dev_sum)
		self._core.io.write(f'SOURce<HwInstance>:FM:DEViation:SUM {param}')

	def set(self, deviation: float, generatorIx=repcap.GeneratorIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:FM<CH>:[DEViation] \n
		Snippet: driver.source.fm.deviation.set(deviation = 1.0, generatorIx = repcap.GeneratorIx.Default) \n
		Sets the modulation deviation of the frequency modulation in Hz. \n
			:param deviation: float The maximum deviation depends on the RF frequency and the selected modulation mode (see data sheet) . Range: 0 to max
			:param generatorIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fm')
		"""
		param = Conversions.decimal_value_to_str(deviation)
		generatorIx_cmd_val = self._cmd_group.get_repcap_cmd_value(generatorIx, repcap.GeneratorIx)
		self._core.io.write(f'SOURce<HwInstance>:FM{generatorIx_cmd_val}:DEViation {param}')

	def get(self, generatorIx=repcap.GeneratorIx.Default) -> float:
		"""SCPI: [SOURce<HW>]:FM<CH>:[DEViation] \n
		Snippet: value: float = driver.source.fm.deviation.get(generatorIx = repcap.GeneratorIx.Default) \n
		Sets the modulation deviation of the frequency modulation in Hz. \n
			:param generatorIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fm')
			:return: deviation: float The maximum deviation depends on the RF frequency and the selected modulation mode (see data sheet) . Range: 0 to max"""
		generatorIx_cmd_val = self._cmd_group.get_repcap_cmd_value(generatorIx, repcap.GeneratorIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FM{generatorIx_cmd_val}:DEViation?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SubPacketCls:
	"""SubPacket commands group definition. 5 total commands, 5 Subgroups, 0 group commands
	Repeated Capability: Subpacket, default value after init: Subpacket.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("subPacket", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_subpacket_get', 'repcap_subpacket_set', repcap.Subpacket.Nr1)

	def repcap_subpacket_set(self, subpacket: repcap.Subpacket) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Subpacket.Default
		Default value after init: Subpacket.Nr1"""
		self._cmd_group.set_repcap_enum_value(subpacket)

	def repcap_subpacket_get(self) -> repcap.Subpacket:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	@property
	def parameters(self):
		"""parameters commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_parameters'):
			from .Parameters import ParametersCls
			self._parameters = ParametersCls(self._core, self._cmd_group)
		return self._parameters

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def toffset(self):
		"""toffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffset'):
			from .Toffset import ToffsetCls
			self._toffset = ToffsetCls(self._core, self._cmd_group)
		return self._toffset

	@property
	def wcodes(self):
		"""wcodes commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wcodes'):
			from .Wcodes import WcodesCls
			self._wcodes = WcodesCls(self._core, self._cmd_group)
		return self._wcodes

	def clone(self) -> 'SubPacketCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SubPacketCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
